require_relative 'spec_helper'
require 'conformity/field'

include Conformity
describe Conformity::Field do
  describe '#value' do
    it "returns a value when there's a value" do
      field = Field.new('field')
      field.value = :value

      expect(field.value).to equal(:value)
    end

    it "raises when there's no value and a field is required" do
      field = Field.new(:field, required: true)
      
      expect { field.value }.to raise_error(Conformity::FieldError)
    end

    it "does not raise when there's no value and a field isn't required" do
      implicit = Field.new(:field)
      explicit = Field.new(:field, required: false)

      expect { implicit.value }.to_not raise_error
      expect { explicit.value }.to_not raise_error
    end
  end

  describe "#value=" do
    it "sets the value" do
      field = Field.new(:boolean, options: ["true", "false"])
      field.value = "true"
      expect(field.value).to match("true")
    end

    it "if options are given it raises an error when trying to set a value not in options" do
      field = Field.new(:field, options: ["one", "two", "three"])
      expect { field.value = "four" }.to raise_error(Conformity::FieldError)
    end
  end

  describe "#required?" do
    it "returns true if a field is required" do
      field = Field.new(:field, required: true)
      expect(field.required?).to be_truthy
    end

    it "returns false if a field is not required" do
      field = Field.new(:field, required: false)
      expect(field.required?).to be_falsey
    end
  end
end
