require_relative 'spec_helper'
require 'conformity/field'

include Conformity
describe Conformity::Fields do
  before :each do
    @fields = Fields.new
  end

  describe "#add_field" do
    it "adds a field to fields" do
      field = double()
      @fields.add_field(field)
      expect(@fields.fields).to include(field)
    end
  end

  describe "#add_new_field" do
    it "adds a new field to fields" do
      @fields.add_new_field(:title, options: ["Ms.", "Mr."])
      allow(Field).to receive(:new) { double("Field", :name => :title) }
      expect(@fields.fields.any? { |f| f.name == :title }).to be_truthy
    end
  end

  describe "#field_names" do
    it "returns the names of added fields" do
      @fields.add_new_field(:name)
      @fields.add_new_field(:title, options: ["Ms.", "Mr."])
      @fields.add_new_field(:email)
      expect(@fields.field_names).to match([:name, :title, :email])
    end
  end

  describe "#value" do
    it "returns the value for field name" do
      field = double("Field", :name => :phone_number, value: '867-5309')
      @fields.add_field(field)
      expect(@fields.value(:phone_number)).to match('867-5309')
    end
  end

  describe "#set" do
    it "sets the value of field name" do
      field = double("Field", name: "number")
      @fields.add_field(field)
      expect(field).to receive(:value=).with("867-5309")
      @fields.set("number", "867-5309")
    end
  end

  describe "#set_all" do
    it "sets the value of all fields" do
      name = double("Field", name: "name")
      number = double("Field", name: "number")
      @fields.add_field(name)
      @fields.add_field(number)

      expect(name).to receive(:value=).with("Jenny")
      expect(number).to receive(:value=).with("867-5309")

      @fields.set_all("name" => "Jenny", "number" => "867-5309")
    end
  end
end
