require_relative 'spec_helper'
require 'conformity/form'
require 'pry'


include Conformity
describe Form do
    before :each do
      @form = Form.new { } # no actions for test
    end
  describe '#initialize' do
    it "initializes with a block" do
      expect do
        Form.new do
          visit '/page'
          find 'element'
          fill_in 'fill_in', with: field(:field_one)
          select field(:field_two)
          choose field(:field_three)
          check 'box'
          uncheck 'box'
          click_on 'button'
        end
      end.to_not raise_error
    end

    it "raises an error when not given a block" do
      expect { Form.new }.to raise_error
    end
  end

  describe '#field' do
    it "should delegate to fields_container" do
      args = :name, { options: ['a', 'b'] }
      expect(@form.fields_container).to receive(:add_new_field).with(*args)
      @form.field(*args)
    end
  end

  describe '#fill' do
    it "delegates to actions" do
      skip "test not implemented"
    end

    it 'raises error on failure' do
      form = Form.new do
        fill_in 'name', with: field(:name)
        click_on 'submit'
      end

      expect { form.fill_with(name: 'Jane Doe') }.to raise_error
    end
  end

  describe "#method_missing" do
    it "ignores actions" do
      expect { @form.fill_in "Name", with: @form.field(:name) }.to_not raise_error
    end
  end
end
