require_relative 'spec_helper'
require 'conformity/success_conditions'


describe SuccessConditions do
  before :each do
    @session = double()
    @sc = SuccessConditions.new(@session)
  end

  describe '#has_content' do
    it 'delegates to the session' do
      @sc.has_content? 'Content'
      expect(@session).to receive(:has_content?).with('Content')
      @sc.success?
    end
  end

  describe '#has_status_code' do
    it 'delegates to the session' do
      @sc.has_status_code? 200
      expect(@session).to receive(:status_code)
      @sc.success?
    end
  end

  describe '#success?' do
    it 'returns true for passing conditions' do
      @sc.has_content? 'Content'
      @sc.has_status_code? 200

      allow(@session).to receive(:has_content?) { true }
      allow(@session).to receive(:status_code) { 200 }

      expect(@sc.success?).to be_truthy
    end

    it 'returns false for failing conditions' do
      @sc.has_content? 'Content'
      @sc.has_status_code? 200

      allow(@session).to receive(:has_content?) { false }
      allow(@session).to receive(:status_code) { 404 }

      expect(@sc.success?).to be_falsy
    end
  end
end
